const express = require('express');
const User = require('../models/user');
const winston = require('winston');

const router = express.Router();

// Logger
const logger = winston.createLogger({
    level: 'info',
    format: winston.format.json(),
    transports: [
        new winston.transports.Console(),
        new winston.transports.File({ filename: 'logs/app.log' })
    ]
});

// CREATE User
router.post('/', async (req, res) => {
    try {
        const { name, email } = req.body;
        const user = new User({ name, email });
        await user.save();
        logger.info(`User created: ${email}`);
        res.status(201).json(user);
    } catch (error) {
        logger.error('Error creating user:', error);
        res.status(500).json({ error: 'Error creating user' });
    }
});

// UPDATE User
router.put('/:id', async (req, res) => {
    try {
        const { name, email } = req.body;
        const user = await User.findByIdAndUpdate(req.params.id, { name, email }, { new: true });
        if (!user) {
            return res.status(404).json({ error: 'User not found' });
        }
        logger.info(`User updated: ${req.params.id}`);
        res.json(user);
    } catch (error) {
        logger.error('Error updating user:', error);
        res.status(500).json({ error: 'Error updating user' });
    }
});

// GET All Users
router.get('/', async (req, res) => {
    try {
        const users = await User.find();
        logger.info('Fetched user list');
        res.json(users);
    } catch (error) {
        logger.error('Error fetching users:', error);
        res.status(500).json({ error: 'Error fetching users' });
    }
});

module.exports = router;
