require('dotenv').config();
const express = require('express');
const mongoose = require('mongoose');
const winston = require('winston');
// const userRoutes = require('./routes/userRoutes');
const userRoutes = require('./routes/userRoutes');

const app = express();
const port = process.env.PORT || 3000;

// Logger Configuration
const logger = winston.createLogger({
    level: 'info',
    format: winston.format.json(),
    transports: [
        new winston.transports.Console(),
        new winston.transports.File({ filename: 'logs/app.log' })
    ]
});

// Middleware
app.use(express.json());
app.use('/api/users', userRoutes);

// MongoDB Connection
mongoose.connect(process.env.MONGO_URI, {
    useNewUrlParser: true,
    useUnifiedTopology: true
}).then(() => logger.info('Connected to MongoDB'))
    .catch(err => logger.error('MongoDB connection error:', err));

app.listen(port, () => {
    logger.info(`Server running on port ${port}`);
});

module.exports = app; // Exporting for testing
